#
# Autogenerated by Thrift
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#

from thrift.Thrift import *
from ttypes import *

EDAM_NOTE_SOURCE_WEB_CLIP = "web.clip"

EDAM_NOTE_SOURCE_MAIL_CLIP = "mail.clip"

EDAM_NOTE_SOURCE_MAIL_SMTP_GATEWAY = "mail.smtp"

